Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Williams2015-08-13 17:56:27 +0000
committerDavid Williams2015-08-13 17:56:27 +0000
commitc437be487ddfe1850905e8f2447721fa0e63da79 (patch)
tree6610ce6f891a461b7f021ce3d985965f390519b7 /production/testScripts/configuration
parentcf991c65f1a5fc9d9ff0a90935e445ee39102e23 (diff)
downloadeclipse.platform.releng.aggregator-c437be487ddfe1850905e8f2447721fa0e63da79.tar.gz
eclipse.platform.releng.aggregator-c437be487ddfe1850905e8f2447721fa0e63da79.tar.xz
eclipse.platform.releng.aggregator-c437be487ddfe1850905e8f2447721fa0e63da79.zip
Bug 474822 - May need to better control/setup Windows environment for
tests
Diffstat (limited to 'production/testScripts/configuration')
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh12
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh12
-rw-r--r--production/testScripts/configuration/sdk.tests/testScripts/runtests.bat12
-rw-r--r--production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh18
4 files changed, 27 insertions, 27 deletions
diff --git a/production/testScripts/configuration/sdk.tests/testScripts/runtests.bat b/production/testScripts/configuration/sdk.tests/testScripts/runtests.bat
index 35d96edba..01d290ec4 100644
--- a/production/testScripts/configuration/sdk.tests/testScripts/runtests.bat
+++ b/production/testScripts/configuration/sdk.tests/testScripts/runtests.bat
@@ -2,7 +2,7 @@
SETLOCAL
REM default java executable for outer and test vm
-set vmcmd=java
+set jvm=java
REM reset list of ant targets in test.xml to execute
set tests=
@@ -46,7 +46,7 @@ if x%1==x-os set os=%2 && shift && shift && goto processcmdlineargs
if x%1==x-arch set arch=%2 && shift && shift && goto processcmdlineargs
if x%1==x-noclean set installmode=noclean&& shift && goto processcmdlineargs
if x%1==x-properties set properties=-propertyfile %2 && shift && shift && goto processcmdlineargs
-if x%1==x-vm set vmcmd="%2" && shift && shift && goto processcmdlineargs
+if x%1==x-vm set jvm="%2" && shift && shift && goto processcmdlineargs
if x%1==x-extdirprop SET extdirproperty="-Djava.ext.dirs=%2" && shift && shift && goto processcmdlineargs
@@ -70,8 +70,8 @@ set
rem -Dtimeout=300000 "%ANT_OPTS%"
-IF NOT EXIST %vmcmd% (
-ECHO ERROR: vmcmd not defined or does not exist: %vmcmd%
+IF NOT EXIST %jvm% (
+ECHO ERROR: jvm not defined or does not exist: %jvm%
exit 1
)
@@ -79,11 +79,11 @@ REM -XshowSettings is supported on windows VMs but ... not every where. So where
REM causes VM to not start at all. Can be handy for diagnostics. (without running ant <echoproperties/>
IF DEFINED extdirproperty (
-%vmcmd% %extdirproperty% -Dosgi.os=%os% -Dosgi.ws=%ws% -Dosgi.arch=%arch% -jar eclipse\plugins\%launcher-jar% -data workspace -application org.eclipse.ant.core.antRunner -file test.xml %tests% -Dws=%ws% -Dos=%os% -Darch=%arch% -D%installmode%=true %properties% -logger org.apache.tools.ant.DefaultLogger
+%jvm% %extdirproperty% -Dosgi.os=%os% -Dosgi.ws=%ws% -Dosgi.arch=%arch% -jar eclipse\plugins\%launcher-jar% -data workspace -application org.eclipse.ant.core.antRunner -file test.xml %tests% -Dws=%ws% -Dos=%os% -Darch=%arch% -D%installmode%=true %properties% -logger org.apache.tools.ant.DefaultLogger
GOTO END
)
-%vmcmd% -Dosgi.os=%os% -Dosgi.ws=%ws% -Dosgi.arch=%arch% -jar eclipse\plugins\%launcher-jar% -data workspace -application org.eclipse.ant.core.antRunner -file test.xml %tests% -Dws=%ws% -Dos=%os% -Darch=%arch% -D%installmode%=true %properties% -logger org.apache.tools.ant.DefaultLogger
+%jvm% -Dosgi.os=%os% -Dosgi.ws=%ws% -Dosgi.arch=%arch% -jar eclipse\plugins\%launcher-jar% -data workspace -application org.eclipse.ant.core.antRunner -file test.xml %tests% -Dws=%ws% -Dos=%os% -Darch=%arch% -D%installmode%=true %properties% -logger org.apache.tools.ant.DefaultLogger
:END
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
index 023cf5e6a..36f55bfe6 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
@@ -6,12 +6,12 @@ ulimit -c unlimited
# somewhere on the search path ($HOME/bin is common),
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
# such as for vmcmd
source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
-vmcmd=${vmcmd:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Commands/java}
+jvm=${jvm:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Commands/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
@@ -19,11 +19,11 @@ vmcmd=${vmcmd:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Comman
eclipseArch=${eclipseArch:-x86}
# vm.properties is used by default on production machines, but will
# need to override on local setups to specify appropriate vm (usually same as vmcmd).
# see bug 388269
propertyFile=${propertyFile:-vm.properties}
-echo "vmcmd in testAll: ${vmcmd}"
+echo "jvm in testAll: ${jvm}"
echo "extdir in testAll (if any): ${extdir}"
echo "propertyFile in testAll: ${propertyFile}"
@@ -33,7 +33,7 @@ echo "propertyFile in testAll: ${propertyFile}"
if [[ -n "${extdir}" ]]
then
- ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -extdirprop "${extdir}" -vm "${vmcmd}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
+ ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -extdirprop "${extdir}" -vm "${jvm}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
else
- ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -vm "${vmcmd}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
+ ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -vm "${jvm}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
fi
@@ -6,12 +6,12 @@ ulimit -c unlimited
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
-# such as for vmcmd
+# such as for jvm
source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
@@ -19,11 +19,11 @@ vmcmd=${vmcmd:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Comman
eclipseArch=${eclipseArch:-x86}
# vm.properties is used by default on production machines, but will
-# need to override on local setups to specify appropriate vm (usually same as vmcmd).
+# need to override on local setups to specify appropriate vm (usually same as jvm).
# see bug 388269
propertyFile=${propertyFile:-vm.properties}
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
index 7ecbabdfb..1c82e603b 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
@@ -6,23 +6,23 @@ ulimit -c unlimited
# somewhere on the search path ($HOME/bin is common),
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
# such as for vmcmd
source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
-vmcmd=${vmcmd:-/Library/Java/JavaVirtualMachines/jdk1.7.0_51.jdk/Contents/Home/jre/bin/java}
+jvm=${jvm:-/Library/Java/JavaVirtualMachines/jdk1.7.0_51.jdk/Contents/Home/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
# this value in localBuildProperties.shsource.
eclipseArch=${eclipseArch:-x86_64}
# vm.properties is used by default on production machines, but will
# need to override on local setups to specify appropriate vm (usually same as vmcmd).
# see bug 388269
propertyFile=${propertyFile:-vm.properties}
-echo "vmcmd in testAll: ${vmcmd}"
+echo "jvm in testAll: ${jvm}"
echo "extdir in testAll (if any): ${extdir}"
echo "propertyFile in testAll: ${propertyFile}"
echo "contents of propertyFile:"
@@ -34,7 +34,7 @@ cat ${propertyFile}
if [[ -n "${extdir}" ]]
then
- ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -extdirprop "${extdir}" -vm "${vmcmd}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
+ ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -extdirprop "${extdir}" -vm "${jvm}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
else
- ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -vm "${vmcmd}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
+ ./runtestsmac.sh -os macosx -ws cocoa -arch $eclipseArch -vm "${jvm}" -properties ${propertyFile} $* > results/consolelogs/${testedPlatform}_consolelog.txt
fi
@@ -6,23 +6,23 @@ ulimit -c unlimited
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
-# such as for vmcmd
+# such as for jvm
source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
@@ -6,23 +6,23 @@ ulimit -c unlimited
eclipseArch=${eclipseArch:-x86_64}
# vm.properties is used by default on production machines, but will
-# need to override on local setups to specify appropriate vm (usually same as vmcmd).
+# need to override on local setups to specify appropriate vm (usually same as jvm).
# see bug 388269
propertyFile=${propertyFile:-vm.properties}
diff --git a/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh b/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
index 20039fc61..e73380ad7 100644
--- a/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
+++ b/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
@@ -5,19 +5,19 @@
# somewhere on the search path ($HOME/bin is common),
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
# such as for vmcmd
source localBuildProperties.shsource 2>/dev/null
# by default, use the java executable on the path for outer and test jvm
-#vmcmd=/shared/common/jdk-1.6.x86_64/jre/bin/java
-if [[ -z "{vmcmd}" ]]
+#jvm=/shared/common/jdk-1.6.x86_64/jre/bin/java
+if [[ -z "{jvm}" ]]
then
- echo "vmcmd was unexpectly undefined, so using 'java'."
- vmcmd=java
+ echo "jvm was unexpectly undefined, so using 'java'."
+ jvm=java
fi
-echo "vmcmd: $vmcmd"
+echo "jvm: $jvm"
#this value must be set when using rsh to execute this script, otherwise the script will execute from the user's home directory
dir=.
@@ -62,7 +62,7 @@ do
-extdirprop)
extdirproperty="-Djava.ext.dirs=${2}";shift;;
-vm)
- vmcmd="${2}"; shift;;
+ jvm="${2}"; shift;;
*)
tests=$tests\ ${1};;
esac
@@ -129,9 +129,9 @@ echo "properties: $properties"
# -Dtimeout=300000 "${ANT_OPTS}"
if [[ ! -z "${extdirproperty}" ]]
then
- $vmcmd "${extdirproperty}" -Dosgi.os=$os -Dosgi.ws=$ws -Dosgi.arch=$arch -jar $launcher -data workspace -application org.eclipse.ant.core.antRunner -file ${PWD}/test.xml $tests -Dws=$ws -Dos=$os -Darch=$arch -D$installmode=true $properties -logger org.apache.tools.ant.DefaultLogger
+ $jvm "${extdirproperty}" -Dosgi.os=$os -Dosgi.ws=$ws -Dosgi.arch=$arch -jar $launcher -data workspace -application org.eclipse.ant.core.antRunner -file ${PWD}/test.xml $tests -Dws=$ws -Dos=$os -Darch=$arch -D$installmode=true $properties -logger org.apache.tools.ant.DefaultLogger
else
- $vmcmd -Dosgi.os=$os -Dosgi.ws=$ws -Dosgi.arch=$arch -jar $launcher -data workspace -application org.eclipse.ant.core.antRunner -file ${PWD}/test.xml $tests -Dws=$ws -Dos=$os -Darch=$arch -D$installmode=true $properties -logger org.apache.tools.ant.DefaultLogger
+ $jvm -Dosgi.os=$os -Dosgi.ws=$ws -Dosgi.arch=$arch -jar $launcher -data workspace -application org.eclipse.ant.core.antRunner -file ${PWD}/test.xml $tests -Dws=$ws -Dos=$os -Darch=$arch -D$installmode=true $properties -logger org.apache.tools.ant.DefaultLogger
fi

Back to the top
@@ -5,19 +5,19 @@
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
-# such as for vmcmd
+# such as for jvm
source localBuildProperties.shsource 2>/dev/null
# by default, use the java executable on the path for outer and test jvm